# biobrary
Python3 library for bioinformatics.  

## Install  
pip install biobrary --user  

## Usage  
import biobrary  
dir(biobrary)  

## bioinformatic file parse.
* biopaser  
      Fasta_parser
* biocondon
* amino_acids_mw
* CircleNond
